.. _install:

Installing tables_io
====================

At this point you can install `tables_io` with `pip` or from source.


Installing with pip
-------------------

This is pretty trivial.

.. code-block:: bash

    pip install tables_io



Installing from source
-----------------------

Since `tables_io` is all python code, this is pretty easy.

.. code-block:: bash

    git clone https://github.com/LSSTDESC/tables_io.git
    cd tables_io
    python setup.py install

